from openhltest_client.base import Base


class Devices(Base):
	"""A list of devices.
	Each devices object can contain 0..n protocols objects

	Implements the iterator interface __iter__ and encapsulates 0..n instances of the openhltest:sessions/config/device-groups/devices resource.
	"""
	YANG_NAME = 'devices'
	YANG_KEYWORD = 'list'
	YANG_KEY = 'name'
	YANG_PROPERTY_MAP = {"ParentLink": "parent-link", "DeviceCountPerPort": "device-count-per-port", "Name": "name"}

	def __init__(self, parent):
		super(Devices, self).__init__(parent)

	@property
	def Protocols(self):
		"""A list of emulated protocols.
		Each emulated protocols object is a container for one and only one of the emulated protocol types.
		The protocol-type is used to specify what type of protocol is contained in a protocols object.

		Get an instance of the Protocols class.

		Returns:
			obj(openhltest_client.openhltest.sessions.config.devicegroups.devices.protocols.protocols.Protocols)
		"""
		from openhltest_client.openhltest.sessions.config.devicegroups.devices.protocols.protocols import Protocols
		return Protocols(self)

	@property
	def Name(self):
		"""The unique name of a devices object.

		Returns:
			string

		Raises (setter only):
			ValueError
			InvalidValueError
		"""
		return self._get_value('name')

	@property
	def DeviceCountPerPort(self):
		"""The number of devices that will be created on each
		abstract test port specified in the port-names list.

		Returns:
			uint32

		Raises (setter only):
			ValueError
			InvalidValueError
		"""
		return self._get_value('device-count-per-port')
	@DeviceCountPerPort.setter
	def DeviceCountPerPort(self, value):
		return self._set_value('device-count-per-port', value)

	@property
	def ParentLink(self):
		"""Identifies which devices object or simulated-networks object is connected to this object.
		This is used to create a devices container behind a devices or simulated networks container.
		An empty link indicates that the object is at the top of the stack.

		Returns:
			union[leafref]

		Raises (setter only):
			ValueError
			InvalidValueError
		"""
		return self._get_value('parent-link')
	@ParentLink.setter
	def ParentLink(self, value):
		return self._set_value('parent-link', value)

	def create(self, Name, DeviceCountPerPort=None, ParentLink=None):
		"""Create an instance of the `devices` resource

		Args:
			Name (string): The unique name of a devices object.
			DeviceCountPerPort (uint32): The number of devices that will be created on eachabstract test port specified in the port-names list.
			ParentLink (union[leafref]): Identifies which devices object or simulated-networks object is connected to this object.This is used to create a devices container behind a devices or simulated networks container.An empty link indicates that the object is at the top of the stack.
		"""
		return self._create(locals())

	def read(self, Name=None):
		"""Get `devices` resource(s). Returns all resources from the server if `Name` is not specified

		"""
		return self._read(Name)

	def delete(self):
		"""Delete all the encapsulated instances of the retrieved `devices` resource

		"""
		return self._delete()

	def update(self, DeviceCountPerPort=None, ParentLink=None):
		"""Update the current instance of the `devices` resource

		Args:
			DeviceCountPerPort (uint32): The number of devices that will be created on eachabstract test port specified in the port-names list.
			ParentLink (union[leafref]): Identifies which devices object or simulated-networks object is connected to this object.This is used to create a devices container behind a devices or simulated networks container.An empty link indicates that the object is at the top of the stack.
		"""
		return self._update(locals())

